#ifndef _LOGIK_H_
#define _LOGIK_H_

#include <qlist.h>

#include <kwin/client.h>

class QSpacerItem;
class QBoxLayout;
class KPixmap;

namespace KWinInternal
{
  class LogikButton;

  class Logik : public KWinInternal::Client
  {
    Q_OBJECT

    public:
        /** Constructor */
      Logik(Workspace *, WId, bool tool, QWidget * parent = 0, const char * name = 0);
        /** Destructor */
      ~Logik();

    protected:

      virtual void resizeEvent(QResizeEvent *);
      virtual void paintEvent(QPaintEvent *);
      virtual void showEvent(QShowEvent *);
      virtual void mouseDoubleClickEvent(QMouseEvent *);

      virtual void windowWrapperShowEvent(QShowEvent *);
      virtual void captionChange(const QString &);
      virtual void stickyChange(bool on);
      virtual void maximizeChange(bool);
      virtual void doShape();
      virtual void activeChange(bool);
      virtual MousePosition mousePosition(const QPoint &) const;
      virtual void animateIconifyOrDeiconify(bool);

    protected slots:

      void slotReset();
      void slotMaximize(int button);
      
    public slots:
      void toggleStayOnTop();

    signals:

      void stkyChange(bool);
      void maxChange(bool);

    private:
      void calculateElements();

      enum ButtonType
      {
        ButtonHelp,
        ButtonSticky,
        ButtonMenu,
        ButtonSeparator,
        ButtonIconify,
        ButtonMaximize,
        ButtonClose,
        ButtonLower
      };

      bool tool;
      bool showStayOnTop;

      LogikButton *   createButton(const QString &, QWidget *  parent);
      void          createButtons();
      void          resetLayout();

      QBoxLayout    * mainLayout;
      QSpacerItem   * middleSpacer;

      QList<LogikButton> leftButtonList;
      QList<LogikButton> rightButtonList;
  };
}

#endif /* _LOGIK_H_ */
