#ifndef _LOGIKBUTTONS_H_
#define _LOGIKBUTTONS_H_

#include <qwidget.h>
#include <qbitmap.h>
#include <kwin/kwinbutton.h>

namespace KWinInternal
{
  class LogikButton : public KWinWidgetButton
  {
    Q_OBJECT

    public:
      LogikButton(QWidget * parent, const QString& tip);

      virtual ~LogikButton();

      virtual QSize sizeHint() const;
      virtual QSize minimumSizeHint() const;

    protected:
      virtual void clickEvent(int button) = 0;

      void setBitmap(const QBitmap &);

      void mousePressEvent(QMouseEvent *);
      void mouseReleaseEvent(QMouseEvent *);
      void enterEvent(QEvent *);
      void leaveEvent(QEvent *);
      void paintEvent(QPaintEvent *);
      void resizeEvent(QResizeEvent *);

    private:
      QBitmap bitmap;

      bool mouseOver;
      bool mouseDown;
  };

  class LogikButtonClose : public LogikButton
  {
    Q_OBJECT

    public:
      LogikButtonClose(QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    signals:
      void closeWindow();
  };

  class LogikButtonHelp : public LogikButton
  {
    Q_OBJECT

    public:
      LogikButtonHelp(QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    signals:
      void help();
  };

  class LogikButtonIconify : public LogikButton
  {
    Q_OBJECT

    public:
      LogikButtonIconify(QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    signals:
      void iconify();
  };

  class LogikButtonLower : public LogikButton
  {
    Q_OBJECT

    public:
      LogikButtonLower(QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    signals:
      void lowerWindow();
  };

  class LogikButtonMaximize : public LogikButton
  {
    Q_OBJECT

    public:
      LogikButtonMaximize(bool maximised, QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    protected slots:
      void slotMaximizeChange(bool);

    signals:
      void maximize(int mode);
  };

  class LogikButtonSticky : public LogikButton
  {
    Q_OBJECT

    public:
      LogikButtonSticky(bool sticky, QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    protected slots:
      void slotStickyChange(bool);

    signals:
      void toggleSticky();
  };

  class LogikButtonStayOnTop : public LogikButton
  {
    Q_OBJECT

    public:
      LogikButtonStayOnTop(QWidget * parent, const QString& tip);

    protected:
      virtual void clickEvent(int button);

    signals:
      void toggleStayOnTop();
  };
}

#endif /* _LOGIKBUTTONS_H_ */

